@@ -16,7 +16,9 @@
 
 #include "process.h"
 
-class QWidget;
+#include "processcore_export.h"
+
+class QWindow;
 
 /**
  * Control processes' priority, scheduling and sending signals.
@@ -28,7 +30,7 @@ class QWidget;
  */
 namespace KSysGuard
 {
-class Q_DECL_EXPORT ProcessController : public QObject
+class PROCESSCORE_EXPORT ProcessController : public QObject
 {
     Q_OBJECT
 
@@ -66,15 +68,15 @@ public:
     Q_ENUM(Result)
 
     /**
-     * The widget used as parent for any dialogs that get shown.
+     * The window used as parent for any dialogs that get shown.
      */
-    QWidget *widget() const;
+    QWindow *window() const;
     /**
-     * Set the widget to use as parent for dialogs.
+     * Set the window to use as parent for dialogs.
      *
-     * \param widget The widget to use.
+     * \param window The window to use.
      */
-    void setWidget(QWidget *widget);
+    void setWindow(QWindow *window);
 
     /**
      * Send a signal to a number of processes.
@@ -90,13 +92,13 @@ public:
      *         that a non-Success result may indicate any of the processes in
      *         \p pids encountered that result.
      */
-    Q_INVOKABLE Result sendSignal(const QVector<int> &pids, int signal);
+    Q_INVOKABLE Result sendSignal(const QList<int> &pids, int signal);
     /**
-     * \overload Result sendSignal(const QVector<int> &pids, int signal)
+     * \overload Result sendSignal(const QList<int> &pids, int signal)
      */
     Q_INVOKABLE Result sendSignal(const QList<long long> &pids, int signal);
     /**
-     * \overload Result sendSignal(const QVector<int> &pids, int signal)
+     * \overload Result sendSignal(const QList<int> &pids, int signal)
      */
     Q_INVOKABLE Result sendSignal(const QVariantList &pids, int signal);
 
@@ -114,13 +116,13 @@ public:
      *         that a non-Success result may indicate any of the processes in
      *         \p pids encountered that result.
      */
-    Q_INVOKABLE Result setPriority(const QVector<int> &pids, int priority);
+    Q_INVOKABLE Result setPriority(const QList<int> &pids, int priority);
     /**
-     * \overload Result setPriority(const QVector<int> &pids, int priority)
+     * \overload Result setPriority(const QList<int> &pids, int priority)
      */
     Q_INVOKABLE Result setPriority(const QList<long long> &pids, int priority);
     /**
-     * \overload Result setPriority(const QVector<int> &pids, int priority)
+     * \overload Result setPriority(const QList<int> &pids, int priority)
      */
     Q_INVOKABLE Result setPriority(const QVariantList &pids, int priority);
 
@@ -140,13 +142,13 @@ public:
      *         that a non-Success result may indicate any of the processes in
      *         \p pids encountered that result.
      */
-    Q_INVOKABLE Result setCPUScheduler(const QVector<int> &pids, Process::Scheduler scheduler, int priority);
+    Q_INVOKABLE Result setCPUScheduler(const QList<int> &pids, Process::Scheduler scheduler, int priority);
     /**
-     * \overload Result setCPUScheduler(const QVector<int> &pids, Process::Scheduler scheduler, int priority)
+     * \overload Result setCPUScheduler(const QList<int> &pids, Process::Scheduler scheduler, int priority)
      */
     Q_INVOKABLE Result setCPUScheduler(const QList<long long> &pids, Process::Scheduler scheduler, int priority);
     /**
-     * \overload Result setCPUScheduler(const QVector<int> &pids, Process::Scheduler scheduler, int priority)
+     * \overload Result setCPUScheduler(const QList<int> &pids, Process::Scheduler scheduler, int priority)
      */
     Q_INVOKABLE Result setCPUScheduler(const QVariantList &pids, Process::Scheduler scheduler, int priority);
 
@@ -166,13 +168,13 @@ public:
      *         that a non-Success result may indicate any of the processes in
      *         \p pids encountered that result.
      */
-    Q_INVOKABLE Result setIOScheduler(const QVector<int> &pids, Process::IoPriorityClass priorityClass, int priority);
+    Q_INVOKABLE Result setIOScheduler(const QList<int> &pids, Process::IoPriorityClass priorityClass, int priority);
     /**
-     * \overload Result setIOScheduler(const QVector<int> &pids, Process::IoPriorityClass priorityClass, int priority)
+     * \overload Result setIOScheduler(const QList<int> &pids, Process::IoPriorityClass priorityClass, int priority)
      */
     Q_INVOKABLE Result setIOScheduler(const QList<long long> &pids, Process::IoPriorityClass priorityClass, int priority);
     /**
-     * \overload Result setIOScheduler(const QVector<int> &pids, Process::IoPriorityClass priorityClass, int priority)
+     * \overload Result setIOScheduler(const QList<int> &pids, Process::IoPriorityClass priorityClass, int priority)
      */
     Q_INVOKABLE Result setIOScheduler(const QVariantList &pids, Process::IoPriorityClass priorityClass, int priority);
 
